==> smart-testauto-framework-5.0.0-sources.jar: org/uitnet/testing/smartfwk/ui/core/objects/UIObject.java <==
/*
 * SmartTestAutoFramework
 * Copyright 2021 and beyond
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */
package org.uitnet.testing.smartfwk.ui.core.objects;

import org.sikuli.script.Region;
import org.uitnet.testing.smartfwk.ui.core.SmartCucumberUiScenarioContext;
import org.uitnet.testing.smartfwk.ui.core.appdriver.SmartAppDriver;
import org.uitnet.testing.smartfwk.ui.core.commons.LocatorType;
import org.uitnet.testing.smartfwk.ui.core.commons.UIObjectType;
import org.uitnet.testing.smartfwk.ui.core.config.AppConfig;

/**
 * 
 * @author Madhav Krishna
 *
 */
public abstract class UIObject {
	protected LocatorType locatorType;
	protected UIObjectType uiObjectType;
	protected String displayName;

	public UIObject(LocatorType locatorType, UIObjectType type, String displayName) {
		this.locatorType = locatorType;
		this.uiObjectType = type;
		this.displayName = displayName;
	}

	public LocatorType getLocatorType() {
		return locatorType;
	}

	public UIObjectType getType() {
		return uiObjectType;
	}

	public String getDisplayName() {
		return displayName;
	}

	public abstract UIObject clone();

	public abstract UIObject updateLocatorParameterWithValue(AppConfig appConfig, String paramName, String value);

	public abstract UIObjectValidator getValidator(SmartAppDriver appDriver, Region region);

	public abstract UIObjectValidator getValidator(SmartCucumberUiScenarioContext scenarioContext, Region region);
}

==> smart-testauto-framework-5.0.1-sources.jar: org/uitnet/testing/smartfwk/ui/core/objects/UIObject.java <==
/*
 * SmartTestAutoFramework
 * Copyright 2021 and beyond
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */
package org.uitnet.testing.smartfwk.ui.core.objects;

import org.sikuli.script.Region;
import org.uitnet.testing.smartfwk.ui.core.SmartCucumberUiScenarioContext;
import org.uitnet.testing.smartfwk.ui.core.appdriver.SmartAppDriver;
import org.uitnet.testing.smartfwk.ui.core.commons.LocatorType;
import org.uitnet.testing.smartfwk.ui.core.commons.UIObjectType;

/**
 * 
 * @author Madhav Krishna
 *
 */
public abstract class UIObject {
	protected LocatorType locatorType;
	protected UIObjectType uiObjectType;
	protected String displayName;

	public UIObject(LocatorType locatorType, UIObjectType type, String displayName) {
		this.locatorType = locatorType;
		this.uiObjectType = type;
		this.displayName = displayName;
	}

	public LocatorType getLocatorType() {
		return locatorType;
	}

	public UIObjectType getType() {
		return uiObjectType;
	}

	public String getDisplayName() {
		return displayName;
	}

	public abstract UIObject clone();

	public abstract UIObject updateLocatorParameterWithValue(String paramName, String value);

	public abstract UIObjectValidator getValidator(SmartAppDriver appDriver, Region region);

	public abstract UIObjectValidator getValidator(SmartCucumberUiScenarioContext scenarioContext, Region region);
}
